@@ -1,13 +1,3 @@
---
--- Table structure for table galette_paypal_types_cotisation_prices
---
-DROP TABLE IF EXISTS galette_paypal_types_cotisation_prices;
-CREATE TABLE galette_paypal_types_cotisation_prices (
-  id_type_cotis integer REFERENCES galette_types_cotisation ON DELETE CASCADE,
-  amount  real DEFAULT '0',
-  PRIMARY KEY (id_type_cotis)
-);
-
 --
 -- Table structure for table galette_paypal_history
 --
